## 美股行情

接口：us_daily

描述：获取美股行情（未复权），包括全部股票全历史行情，以及重要的市场和估值指标

限量：单次最大6000行数据，可根据日期参数循环提取，开通正式权限后也可支持分页提取全部历史

要求：120积分可以试用查看数据，开通正式权限请参考权限说明文档。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码（e.g. AAPL） |
| trade_date | str | N | 交易日期（YYYYMMDD） |
| start_date | str | N | 开始日期（YYYYMMDD） |
| end_date | str | N | 结束日期（YYYYMMDD） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 收盘价 |
| open | float | Y | 开盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| pre_close | float | Y | 昨收价 |
| change | float | N | 涨跌额 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量 |
| amount | float | Y | 成交额 |
| vwap | float | Y | 平均价 |
| turnover_ratio | float | N | 换手率 |
| total_mv | float | N | 总市值 |
| pe | float | N | PE |
| pb | float | N | PB |

接口示例

```python
pro = ts.pro_api()

#获取单一股票行情
df = pro.us_daily(ts_code='AAPL', start_date='20190101', end_date='20190904')

#获取某一日所有股票
df = pro.us_daily(trade_date='20190904')
```

数据示例

```python
ts_code trade_date   close    open    high     low pre_close pct_change       vol              amount    vwap
0      AAPL   20190904  209.19  208.39  209.48  207.32    205.70       1.70  19216821   4008342529.970000  208.59
```